@@ -15,15 +15,12 @@
 import abc
 import logging
 
-import six
-
 from sushy import exceptions
 
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AuthBase(object):
+class AuthBase(object, metaclass=abc.ABCMeta):
 
     def __init__(self, username=None, password=None):
         """A class representing a base Sushy authentication mechanism
@@ -152,18 +149,10 @@ class SessionAuth(AuthBase):
         :raises: AccessError
         :raises: HTTPError
         """
-        target_uri = None
-        try:
-            target_uri = self._root_resource.get_sessions_path()
-        except exceptions.MissingAttributeError:
-            LOG.debug('Missing Sessions attribute under Links in Root '
-                      'Service, we\'ll try to determine it from Session '
-                      'Service')
         session_service = self._root_resource.get_session_service()
         session_auth_token, session_uri = (
             session_service.create_session(self._username,
-                                           self._password,
-                                           target_uri=target_uri))
+                                           self._password))
         self._session_key = session_auth_token
         self._session_resource_id = session_uri
         self._connector.set_http_session_auth(session_auth_token)
