@@ -13,10 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import logging
 
-from six.moves import http_client
-
 
 LOG = logging.getLogger(__name__)
 
@@ -61,6 +60,10 @@ class ArchiveParsingError(SushyError):
     message = 'Failed parsing archive "%(path)s": %(error)s'
 
 
+class UnknownDefaultError(SushyError):
+    message = 'Failed at determining default for "%(entity)s": %(error)s'
+
+
 class ExtensionError(SushyError):
     message = ('Sushy Extension Error: %(error)s')
 
@@ -101,9 +104,9 @@ class HTTPError(SushyError):
             self.code = self.body.get('code', 'Base.1.0.GeneralError')
             self.detail = self.body.get('message')
             ext_info = self.body.get('@Message.ExtendedInfo', [{}])
-            message = self._get_most_severe_msg(ext_info)
-            self.detail = message or self.detail
-            error = '%s: %s' % (self.code, self.detail or 'unknown error.')
+            index = self._get_most_severe_msg_index(ext_info)
+            self.detail = ext_info[index].get('Message', self.detail)
+            error = '%s: %s' % (self.code, self.detail or 'unknown error')
 
         kwargs = {'method': method, 'url': url, 'code': self.status_code,
                   'error': error}
@@ -112,14 +115,13 @@ class HTTPError(SushyError):
         super(HTTPError, self).__init__(**kwargs)
 
     @staticmethod
-    def _get_most_severe_msg(extended_info):
-        if not isinstance(extended_info, list):
-            return extended_info.get('Message', None)
+    def _get_most_severe_msg_index(extended_info):
         if len(extended_info) > 0:
             for sev in ['Critical', 'Warning']:
                 for i, m in enumerate(extended_info):
                     if m.get('Severity') == sev:
-                        return m.get('Message')
+                        return i
+        return 0
 
 
 class BadRequestError(HTTPError):
