@@ -12,11 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import json
 import mock
 
 from dateutil import parser
-from six.moves import http_client
 
 from sushy import exceptions
 from sushy.resources.registry import message_registry
@@ -170,18 +170,6 @@ class BiosTestCase(base.TestCase):
         self.sys_bios.reset_bios()
         self.sys_bios._conn.post.assert_has_calls(post_calls)
 
-    def test_reset_bios_handle_http_error_400(self):
-
-        target_uri = (
-            '/redfish/v1/Systems/437XR1138R2/BIOS/Actions/Bios.ResetBios')
-        self.conn.post.side_effect = [exceptions.HTTPError(
-            method='POST', url=target_uri, response=mock.MagicMock(
-                status_code=http_client.BAD_REQUEST)), '200']
-        post_calls = [
-            mock.call(target_uri), mock.call(target_uri, data={})]
-        self.sys_bios.reset_bios()
-        self.sys_bios._conn.post.assert_has_calls(post_calls)
-
     def test_reset_bios_handle_http_error_405(self):
 
         target_uri = (
