@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import json
 
 import mock
 import requests
-from six.moves import http_client
 
 from sushy import auth as sushy_auth
 from sushy import connector
@@ -48,35 +48,80 @@ class ConnectorMethodsTestCase(base.TestCase):
         self.conn.get(path='fake/path', data=self.data.copy(),
                       headers=self.headers.copy())
         mock__op.assert_called_once_with(mock.ANY, 'GET', 'fake/path',
-                                         data=self.data, headers=self.headers)
+                                         data=self.data, headers=self.headers,
+                                         blocking=False, timeout=60)
+
+    @mock.patch.object(connector.Connector, '_op', autospec=True)
+    def test_get_blocking(self, mock__op):
+        self.conn.get(path='fake/path', data=self.data.copy(),
+                      headers=self.headers.copy(), blocking=True)
+        mock__op.assert_called_once_with(mock.ANY, 'GET', 'fake/path',
+                                         data=self.data, headers=self.headers,
+                                         blocking=True, timeout=60)
 
     @mock.patch.object(connector.Connector, '_op', autospec=True)
     def test_post(self, mock__op):
         self.conn.post(path='fake/path', data=self.data.copy(),
                        headers=self.headers.copy())
         mock__op.assert_called_once_with(mock.ANY, 'POST', 'fake/path',
-                                         data=self.data, headers=self.headers)
+                                         data=self.data, headers=self.headers,
+                                         blocking=False, timeout=60)
+
+    @mock.patch.object(connector.Connector, '_op', autospec=True)
+    def test_post_blocking(self, mock__op):
+        self.conn.post(path='fake/path', data=self.data.copy(),
+                       headers=self.headers.copy(), blocking=True, timeout=120)
+        mock__op.assert_called_once_with(mock.ANY, 'POST', 'fake/path',
+                                         data=self.data, headers=self.headers,
+                                         blocking=True, timeout=120)
 
     @mock.patch.object(connector.Connector, '_op', autospec=True)
     def test_patch(self, mock__op):
         self.conn.patch(path='fake/path', data=self.data.copy(),
                         headers=self.headers.copy())
         mock__op.assert_called_once_with(mock.ANY, 'PATCH', 'fake/path',
-                                         data=self.data, headers=self.headers)
+                                         data=self.data, headers=self.headers,
+                                         blocking=False, timeout=60)
+
+    @mock.patch.object(connector.Connector, '_op', autospec=True)
+    def test_patch_blocking(self, mock__op):
+        self.conn.patch(path='fake/path', data=self.data.copy(),
+                        headers=self.headers.copy(), blocking=True)
+        mock__op.assert_called_once_with(mock.ANY, 'PATCH', 'fake/path',
+                                         data=self.data, headers=self.headers,
+                                         blocking=True, timeout=60)
 
     @mock.patch.object(connector.Connector, '_op', autospec=True)
     def test_put(self, mock__op):
         self.conn.put(path='fake/path', data=self.data.copy(),
                       headers=self.headers.copy())
         mock__op.assert_called_once_with(mock.ANY, 'PUT', 'fake/path',
-                                         data=self.data, headers=self.headers)
+                                         data=self.data, headers=self.headers,
+                                         blocking=False, timeout=60)
+
+    @mock.patch.object(connector.Connector, '_op', autospec=True)
+    def test_put_blocking(self, mock__op):
+        self.conn.put(path='fake/path', data=self.data.copy(),
+                      headers=self.headers.copy(), blocking=True)
+        mock__op.assert_called_once_with(mock.ANY, 'PUT', 'fake/path',
+                                         data=self.data, headers=self.headers,
+                                         blocking=True, timeout=60)
 
     @mock.patch.object(connector.Connector, '_op', autospec=True)
     def test_delete(self, mock__op):
         self.conn.delete(path='fake/path', data=self.data.copy(),
                          headers=self.headers.copy())
         mock__op.assert_called_once_with(mock.ANY, 'DELETE', 'fake/path',
-                                         data=self.data, headers=self.headers)
+                                         data=self.data, headers=self.headers,
+                                         blocking=False, timeout=60)
+
+    @mock.patch.object(connector.Connector, '_op', autospec=True)
+    def test_delete_blocking(self, mock__op):
+        self.conn.delete(path='fake/path', data=self.data.copy(),
+                         headers=self.headers.copy(), blocking=True)
+        mock__op.assert_called_once_with(mock.ANY, 'DELETE', 'fake/path',
+                                         data=self.data, headers=self.headers,
+                                         blocking=True, timeout=60)
 
     def test_set_auth(self):
         mock_auth = mock.MagicMock()
@@ -158,7 +203,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._session.headers['X-Auth-Token'] = 'asdf1234'
         expected_headers = self.headers.copy()
         expected_headers['OData-Version'] = '4.0'
-        expected_headers['Content-Type'] = 'application/json'
         self.conn._op('POST', path='fake/path', headers=self.headers,
                       data=self.data)
         self.request.assert_called_once_with(
@@ -255,21 +299,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertIsNotNone(exc.body)
         self.assertIn('body submitted was malformed JSON', exc.detail)
 
-    def test_known_http_error_nonlist_ext_info(self):
-        self.request.return_value.status_code =\
-            http_client.UNSUPPORTED_MEDIA_TYPE
-        with open('sushy/tests/unit/json_samples/'
-                  'error_single_ext_info.json') as f:
-            self.request.return_value.json.return_value = json.load(f)
-
-        with self.assertRaisesRegex(exceptions.HTTPError,
-                                    'See Resolution for information') as cm:
-            self.conn._op('POST', 'http://foo.bar')
-        exc = cm.exception
-        self.assertEqual(http_client.UNSUPPORTED_MEDIA_TYPE, exc.status_code)
-        self.assertIsNotNone(exc.body)
-        self.assertIn('See Resolution for information', exc.detail)
-
     def test_not_found_error(self):
         self.request.return_value.status_code = http_client.NOT_FOUND
         self.request.return_value.json.side_effect = ValueError('no json')
@@ -302,3 +331,10 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
+
+    def test_blocking_no_location_header(self):
+        self.request.return_value.status_code = http_client.ACCEPTED
+        self.request.return_value.headers = {'retry-after': 5}
+        with self.assertRaisesRegex(exceptions.ConnectionError,
+                                    'status 202, but no Location header'):
+            self.conn._op('POST', 'http://foo.bar', blocking=True)
