@@ -116,6 +116,41 @@ class MainTestCase(base.TestCase):
             redfish_version=self.root.redfish_version,
             registries=mock_registries)
 
+    @mock.patch.object(system, 'SystemCollection', autospec=True)
+    @mock.patch.object(system, 'System', autospec=True)
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_get_system_default_ok(
+            self, mock_registries, mock_system, mock_system_collection):
+        self.root._standard_message_registries_path = None
+        mock_system.path = 'fake-system-id'
+        mock_members = mock_system_collection.return_value.get_members
+        mock_members.return_value = [mock_system]
+        self.root.get_system()
+        mock_system_collection.assert_called_once_with(
+            self.root._conn, '/redfish/v1/Systems',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+        mock_system.assert_called_once_with(
+            self.root._conn, 'fake-system-id',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries)
+
+    @mock.patch.object(system, 'SystemCollection', autospec=True)
+    @mock.patch.object(system, 'System', autospec=True)
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_get_system_default_failure(
+            self, mock_registries, mock_system, mock_system_collection):
+        self.root._standard_message_registries_path = None
+        mock_members = mock_system_collection.return_value.get_members
+        mock_members.return_value = []
+        self.assertRaises(exceptions.UnknownDefaultError, self.root.get_system)
+        mock_system_collection.assert_called_once_with(
+            self.root._conn, '/redfish/v1/Systems',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+
     @mock.patch.object(chassis, 'Chassis', autospec=True)
     def test_get_chassis(self, mock_chassis):
         self.root.get_chassis('fake-chassis-id')
@@ -123,6 +158,43 @@ class MainTestCase(base.TestCase):
             self.root._conn, 'fake-chassis-id',
             self.root.redfish_version, self.root.registries)
 
+    @mock.patch.object(chassis, 'ChassisCollection', autospec=True)
+    @mock.patch.object(chassis, 'Chassis', autospec=True)
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_get_chassis_default_ok(
+            self, mock_registries, mock_chassis, mock_chassis_collection):
+        self.root._standard_message_registries_path = None
+        mock_chassis.path = 'fake-chassis-id'
+        mock_members = mock_chassis_collection.return_value.get_members
+        mock_members.return_value = [mock_chassis]
+        self.root.get_chassis()
+        mock_chassis_collection.assert_called_once_with(
+            self.root._conn, '/redfish/v1/Chassis',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+        mock_chassis.assert_called_once_with(
+            self.root._conn, 'fake-chassis-id',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+
+    @mock.patch.object(chassis, 'ChassisCollection', autospec=True)
+    @mock.patch.object(chassis, 'Chassis', autospec=True)
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_get_chassis_default_failure(
+            self, mock_registries, mock_chassis, mock_chassis_collection):
+        self.root._standard_message_registries_path = None
+        mock_members = mock_chassis_collection.return_value.get_members
+        mock_members.return_value = []
+        self.assertRaises(
+            exceptions.UnknownDefaultError, self.root.get_chassis)
+        mock_chassis_collection.assert_called_once_with(
+            self.root._conn, '/redfish/v1/Chassis',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+
     @mock.patch.object(chassis, 'ChassisCollection', autospec=True)
     def test_get_chassis_collection(self, chassis_collection_mock):
         self.root.get_chassis_collection()
@@ -158,6 +230,42 @@ class MainTestCase(base.TestCase):
             self.root._conn, 'fake-manager-id',
             self.root.redfish_version, self.root.registries)
 
+    @mock.patch.object(manager, 'ManagerCollection', autospec=True)
+    @mock.patch.object(manager, 'Manager', autospec=True)
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_get_manager_default_ok(
+            self, mock_registries, mock_manager, mock_manager_collection):
+        self.root._standard_message_registries_path = None
+        mock_manager.path = 'fake-manager-id'
+        mock_members = mock_manager_collection.return_value.get_members
+        mock_members.return_value = [mock_manager]
+        self.root.get_manager()
+        mock_manager_collection.assert_called_once_with(
+            self.root._conn, '/redfish/v1/Managers',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+        mock_manager.assert_called_once_with(
+            self.root._conn, 'fake-manager-id',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries)
+
+    @mock.patch.object(manager, 'ManagerCollection', autospec=True)
+    @mock.patch.object(manager, 'Manager', autospec=True)
+    @mock.patch('sushy.Sushy.registries', autospec=True)
+    def test_get_manager_default_failure(
+            self, mock_registries, mock_manager, mock_system_collection):
+        self.root._standard_message_registries_path = None
+        mock_members = mock_system_collection.return_value.get_members
+        mock_members.return_value = []
+        self.assertRaises(
+            exceptions.UnknownDefaultError, self.root.get_manager)
+        mock_system_collection.assert_called_once_with(
+            self.root._conn, '/redfish/v1/Managers',
+            redfish_version=self.root.redfish_version,
+            registries=mock_registries
+        )
+
     @mock.patch.object(sessionservice, 'SessionService', autospec=True)
     def test_get_sessionservice(self, mock_sess_serv):
         self.root.get_session_service()
@@ -275,10 +383,6 @@ class MainTestCase(base.TestCase):
         registries = self.root.registries
         self.assertEqual({'RegistryA.2.0': mock_msg_reg1}, registries)
 
-    def test_get_sessions_path(self):
-        expected = '/redfish/v1/SessionService/Sessions'
-        self.assertEqual(expected, self.root.get_sessions_path())
-
 
 class BareMinimumMainTestCase(base.TestCase):
 
@@ -321,15 +425,11 @@ class BareMinimumMainTestCase(base.TestCase):
             exceptions.MissingAttributeError,
             'UpdateService/@odata.id', self.root.get_update_service)
 
-    def test_get_composition_service_when_compositionservice_attr_absent(self):
+    def test_get_composition_service_when_compositionservice_attr_absent(
+        self):
         self.assertRaisesRegex(
             exceptions.MissingAttributeError,
             'CompositionService/@odata.id', self.root.get_composition_service)
 
     def test__get_registry_collection_when_registries_attr_absent(self):
         self.assertIsNone(self.root._get_registry_collection())
-
-    def test_get_sessions_path_fail(self):
-        self.assertRaisesRegex(
-            exceptions.MissingAttributeError,
-            'Links/Sessions/@data.id', self.root.get_sessions_path)
